@@ -21,7 +21,6 @@
 #include "dialog_p.h"
 
 #include "dispatcher.h"
-//#include "componentsdialog_p.h"
 
 #include <klocalizedstring.h>
 #include <kservicegroup.h>
@@ -157,7 +156,8 @@ QSet<KCModuleInfo> DialogPrivate::instanceServices()
             KSycocaEntry::Ptr p = (*it);
             if (p->isType(KST_KService)) {
                 //qDebug() << "found service";
-                ret << KCModuleInfo(KService::Ptr(p));
+                const KService::Ptr service(static_cast<KService*>(p.data()));
+                ret << KCModuleInfo(service);
             } else
                 qWarning() << "KServiceGroup::childGroup returned"
                            " something else than a KService" << endl;
@@ -305,16 +305,16 @@ void DialogPrivate::createDialogFromServices()
 {
     Q_Q(Dialog);
     // read .setdlg files   (eg: share/kapp/kapp.setdlg)
-    QString setdlgpath = QStandardPaths::locate(QStandardPaths::DataLocation /*includes appname, too*/,
+    const QString setdlgpath = QStandardPaths::locate(QStandardPaths::DataLocation /*includes appname, too*/,
                          QCoreApplication::instance()->applicationName() + QStringLiteral(".setdlg"));
     if (!setdlgpath.isEmpty()) {
         parseGroupFile(setdlgpath);
     }
 
     const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("ksettingsdialog"),  QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
+    for (const QString &dir : dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.setdlg"));
-        Q_FOREACH (const QString &file, fileNames) {
+        for (const QString &file : fileNames) {
             parseGroupFile(dir + QLatin1Char('/') + file);
         }
     }
@@ -343,7 +343,7 @@ void DialogPrivate::createDialogFromServices()
                         const KService::Ptr service = info.service();
                         // FIXME get weight from service or plugin info
                         const int weight = 1000;
-                        KPageWidgetItem *item = createPageItem(0, service->name(), service->comment(), service->icon(), weight);
+                        KPageWidgetItem *item = createPageItem(nullptr, service->name(), service->comment(), service->icon(), weight);
                         connectItemCheckBox(item, pinfo, pinfo.isPluginEnabled());
                         foundPlugin = true;
                         break;
@@ -430,8 +430,8 @@ void DialogPrivate::createDialogFromServices()
     // I have no idea how to check that in KPluginSelector::load()...
     //q->showButton(KDialog::User1, true);
 
-    QObject::connect(q, SIGNAL(okClicked()), q, SLOT(_k_syncConfiguration()));
-    QObject::connect(q, SIGNAL(applyClicked()), q, SLOT(_k_syncConfiguration()));
+    QObject::connect(q->button(QDialogButtonBox::Ok), SIGNAL(clicked()), q, SLOT(_k_syncConfiguration()));
+    QObject::connect(q->button(QDialogButtonBox::Apply), SIGNAL(clicked()), q, SLOT(_k_syncConfiguration()));
     QObject::connect(q, SIGNAL(configCommitted(QByteArray)), q,
                      SLOT(_k_reparseConfiguration(QByteArray)));
 }
@@ -447,8 +447,8 @@ void DialogPrivate::connectItemCheckBox(KPageWidgetItem *item, const KPluginInfo
     checkBox->setVisible(!isPluginImmutable(pinfo));
     checkBox->setChecked(isEnabled);
     q->connect(item, SIGNAL(toggled(bool)), q, SLOT(_k_updateEnabledState(bool)));
-    q->connect(item, SIGNAL(toggled(bool)), checkBox, SLOT(setChecked(bool)));
-    q->connect(checkBox, SIGNAL(clicked(bool)), item, SLOT(setChecked(bool)));
+    q->connect(item, &KPageWidgetItem::toggled, checkBox, &QAbstractButton::setChecked);
+    q->connect(checkBox, &QAbstractButton::clicked, item, &KPageWidgetItem::setChecked);
 }
 
 void DialogPrivate::_k_syncConfiguration()
